//#define XERR
#include "tumorinfo.ih"

TumorInfo::TumorInfo(Scenario const &scenario)
:
    d_incidence(scenario),
    d_beir7(scenario),
    d_growth(scenario),
    d_survival(scenario)
//    d_totalriskFile(scenario.options().totalriskFile())
{}
